/******************************************************************************
 * Lemonade JS
 * https://lemonadejs.com
 *
 * ----
 *
 * Utility
 *
 *  Methods for date/time formatting and conversion
 *
 *****************************************************************************/

/**
 * Utility
 * @constructor
 */
function Utility() {}

/**
 * Current unixtime
 * @param {date|string} date
 * @return {number}
 */
Utility.prototype.time = function(date) {
    return Math.round(this.microtime(date) / 1000);
};

/**
 * Current microtime
 * @param {date|string} date
 * @return {number}
 */
Utility.prototype.microtime = function(date) {
    if (date instanceof Date) {
        return date.getTime();
    } else if (typeof date === 'string') {
        return new Date(date).getTime();
    } else {
        return new Date().getTime();
    }
};

/**
 * Format date
 * @param {Date|string} date
 * @param {string} format
 */
Utility.prototype.date = function(date, format) {

    if (typeof date === 'string') {
        date = new Date(date);
    } else if (!(date instanceof Date)) {
        date = new Date();
    }

    var  day    = date.getDate()
        ,month  = date.getMonth()
        ,year   = date.getFullYear()
        ,yr     = year.toString().substring(2,4)
        ,min    = date.getMinutes()
        ,hour   = date.getHours()
        ,sec    = date.getSeconds();

    format = format.replace('Y', year);
    format = format.replace('y', yr);
    format = format.replace('d', day);
    format = format.replace('m', month);
    format = format.replace('h', hour);
    format = format.replace('i', min);
    format = format.replace('s', sec);

    return format;
};

/**
 * Export
 */
exports = module.exports = Utility;